@@ -14,7 +14,11 @@ h.listDataTags()
 """
 
 from __future__ import (absolute_import, division, print_function, unicode_literals)
-import pkg_resources
+try:
+    from importlib.metadata import version, PackageNotFoundError
+except ImportError:
+    from importlib_metadata import version, PackageNotFoundError  # backport for Python < 3.8
+
 from eigeningenuity.core import EigenServer
 from eigeningenuity.historian import get_historian, list_historians, get_default_historian_name
 from eigeningenuity.historianmulti import get_historian_multi
@@ -24,6 +28,10 @@ from eigeningenuity.assetmodel import get_assetmodel
 from eigeningenuity.smartdash import get_smartdash
 from eigeningenuity.sql import get_sql
 from eigeningenuity.settings import set_azure_tenant_id, set_azure_client_id, set_azure_client_secret, disable_azure_auth, disable_auth_token_cache, clear_auth_token_cache, set_api_token, set_auth_scope
+from eigeningenuity.util import EigenException
 
-__all__ = ["get_historian", "get_historian_multi", "get_assetmodel", "get_elastic", "get_sql", "get_eventlog", "get_smartdash", "list_historians", "EigenServer", "set_azure_tenant_id", "set_azure_client_id", "set_azure_client_secret", "disable_azure_auth", "disable_auth_token_cache", "clear_auth_token_cache", "set_api_token", "set_auth_scope"]
-__version__ = pkg_resources.require("python-eigen-ingenuity")[0].version
+__all__ = ["get_historian", "get_historian_multi", "get_assetmodel", "get_elastic", "get_sql", "get_eventlog", "get_smartdash", "list_historians", "EigenServer", "set_azure_tenant_id", "set_azure_client_id", "set_azure_client_secret", "disable_azure_auth", "disable_auth_token_cache", "clear_auth_token_cache", "set_api_token", "set_auth_scope", "EigenException"]
+try:
+    __version__ = version("python-eigen-ingenuity")
+except PackageNotFoundError:
+    __version__ = "unknown"
