@@ -740,7 +740,7 @@ def get_historian(instance: str = None, eigenserver: EigenServer = None) -> Json
     """
     if eigenserver is None:
         eigenserver = get_default_server()
-    elif type(eigenserver) == str:
+    elif isinstance(eigenserver, str):
         eigenserver = EigenServer(eigenserver)
 
     if instance is not None and (instance.startswith("http:") or instance.startswith("https:")):
