@@ -63,9 +63,9 @@ def _convert_sys_argv_(func):
 @_convert_sys_argv_
 def build(path:str='.', config:str='config.ini', configsection:str='', file:str='', query:list=[], preprocess:list=[], postprocess:list=[], delete_all:list=[], separator:str=';',
             start_from:int=1, end_at:int=1, no_versions:bool=False, no_system_properties:bool=False, ignore_nodes:bool=False, skip_duplicates:bool=False,
-            no_duplicates:bool=False, allow_blanks:list=[], batch:int=0, auth:bool=False, order:str='qnrc', filetypes:str='qnrc', primary_property:str='', required_labels:list=[],
-            required_properties:list=[], database:str='0', verify:bool=False, summarise:bool=False, show_queries:bool=False, show_returns:bool=False,
-            write_queries:str='', write_returns:str='', display_rate='auto', create_node_csv_file:bool=False, node_labels:list=[], node_properties:list=[],
+            no_duplicates:bool=False, allow_blanks:list=[], replace_blanks:str='', batch:int=0, auth:bool=False, order:str='qnrc', filetypes:str='qnrc', primary_property:str='',
+            required_labels:list=[], required_properties:list=[], required_relationship_properties:list=[], database:str='0', verify:bool=False, summarise:bool=False, show_queries:bool=False, show_returns:bool=False,
+            write_queries:str='', write_returns:str='', display_rate='auto', min_display_rate=0, create_node_csv_file:bool=False, node_labels:list=[], node_properties:list=[],
             csv_file_suffix:str='', create_relationship_csv_file:bool=False, csv_to_labels:list=[], csv_to_properties:str=''):
     """The main model builder tools, features a suite of options that allow for importing, exporting, building and updating neo4j data models
 
@@ -90,6 +90,7 @@ def build(path:str='.', config:str='config.ini', configsection:str='', file:str=
             ignore_nodes: Treat node columns in relationship files as relationship properties
             skip_duplicates: Don't create a version node if there are no changes. Same as -nod
             allow_blanks: List of properties to create even if blank
+            replace_blanks: Used in combination with allowblanks. Write a specific value instead of blank e.g "__NULL"
             batch: Number of queries to batch together when processing a node .csv file, significantly improves performance
             auth: Enable Azure Authentication
             order: Order in which to process the input files. Default is qnrc
@@ -99,6 +100,7 @@ def build(path:str='.', config:str='config.ini', configsection:str='', file:str=
             primary_property: Primary property
             required_labels: Required labels - appended to contents of config; use !Label to remove
             required_properties: Required properties - appended to contents of config; use !property to remove
+            required_relationship_properties: Required relationship properties - appended to contents of config; use !property to remove
 
             # What output is required
             verify: Display the generated queries, but do not process them
@@ -108,6 +110,7 @@ def build(path:str='.', config:str='config.ini', configsection:str='', file:str=
             write_queries: Name of a file to record the processed queries. No effect if -v present
             write_returns: Name of a file to record the results of the queries. No effect if -v present
             display_rate: Set the frequency of progress update messages. No effect if -v present
+            min_display_rate: Set the minimum frequency of progress update messages. No effect if -v present or displayrate not set to auto
 
             # Control of the CSV writer
             create_node_csv_file: Create Node csv file(s) from Asset Model'
